@@ -76,7 +76,7 @@ customization:
   branding: ` + DEFAULT_BRAND + `
   documentationBaseURL: ` + DEFAULT_DOC_URL + `
 servingInfo:
-  bindAddress: https://0.0.0.0:8443
+  bindAddress: https://[::]:8443
   certFile: /var/serving-cert/tls.crt
   keyFile: /var/serving-cert/tls.key
 providers: {}
@@ -94,7 +94,7 @@ providers: {}
 apiVersion: console.openshift.io/v1
 customization:
   branding: online
-  documentationBaseURL: https://docs.okd.io/4.2/
+  documentationBaseURL: https://docs.okd.io/4.3/
 `,
 					},
 				},
@@ -127,9 +127,9 @@ clusterInfo:
   masterPublicURL: ` + mockAPIServer + `
 customization:
   branding: online 
-  documentationBaseURL: https://docs.okd.io/4.2/
+  documentationBaseURL: https://docs.okd.io/4.3/
 servingInfo:
-  bindAddress: https://0.0.0.0:8443
+  bindAddress: https://[::]:8443
   certFile: /var/serving-cert/tls.crt
   keyFile: /var/serving-cert/tls.key
 providers: {}
@@ -156,7 +156,7 @@ providers: {}
 apiVersion: console.openshift.io/v1
 customization:
   branding: online
-  documentationBaseURL: https://docs.okd.io/4.2/
+  documentationBaseURL: https://docs.okd.io/4.3/
 `,
 					},
 				},
@@ -191,7 +191,7 @@ customization:
   branding: ` + string(operatorv1.BrandDedicated) + `
   documentationBaseURL: ` + mockOperatorDocURL + `
 servingInfo:
-  bindAddress: https://0.0.0.0:8443
+  bindAddress: https://[::]:8443
   certFile: /var/serving-cert/tls.crt
   keyFile: /var/serving-cert/tls.key
 providers: {}
@@ -223,7 +223,7 @@ providers: {}
 apiVersion: console.openshift.io/v1
 customization:
   branding: online
-  documentationBaseURL: https://docs.okd.io/4.2/
+  documentationBaseURL: https://docs.okd.io/4.3/
 `,
 					},
 				},
@@ -260,7 +260,7 @@ customization:
   customLogoFile: /var/logo/logo.svg
   customProductName: custom-product-name
 servingInfo:
-  bindAddress: https://0.0.0.0:8443
+  bindAddress: https://[::]:8443
   certFile: /var/serving-cert/tls.crt
   keyFile: /var/serving-cert/tls.key
 providers: {}
@@ -292,7 +292,7 @@ providers: {}
 apiVersion: console.openshift.io/v1
 customization:
   branding: online
-  documentationBaseURL: https://docs.okd.io/4.2/
+  documentationBaseURL: https://docs.okd.io/4.3/
 `,
 					},
 				},
@@ -327,7 +327,7 @@ customization:
   branding: ` + string(operatorv1.BrandDedicated) + `
   documentationBaseURL: ` + mockOperatorDocURL + `
 servingInfo:
-  bindAddress: https://0.0.0.0:8443
+  bindAddress: https://[::]:8443
   certFile: /var/serving-cert/tls.crt
   keyFile: /var/serving-cert/tls.key
 providers: 
@@ -484,7 +484,7 @@ func Test_extractYAML(t *testing.T) {
 apiVersion: console.openshift.io/v1
 customization:
   branding: online
-  documentationBaseURL: https://docs.okd.io/4.2/
+  documentationBaseURL: https://docs.okd.io/4.3/
 `,
 					},
 					BinaryData: nil,
@@ -494,7 +494,7 @@ customization:
 apiVersion: console.openshift.io/v1
 customization:
   branding: online
-  documentationBaseURL: https://docs.okd.io/4.2/
+  documentationBaseURL: https://docs.okd.io/4.3/
 `,
 		},
 	}
